
XEP-0045: Multi-User Chat
=========================

.. module:: slixmpp.plugins.xep_0045

.. autoclass:: XEP_0045
    :member-order: bysource
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0045.stanza
    :members:
    :undoc-members:

